# CrazyHusk

Dependency-free Python object wrappers for working with Unreal Engine

[![PyPI](https://img.shields.io/pypi/v/crazyhusk.svg)][pypi_]
[![Status](https://img.shields.io/pypi/status/crazyhusk.svg)][status]
[![Python Version](https://img.shields.io/pypi/pyversions/crazyhusk)][python version]
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)][license]

[![Read the documentation at https://crazyhusk.readthedocs.io/](https://img.shields.io/readthedocs/crazyhusk/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Tests](https://github.com/nhaines-pro/python-crazyhusk/workflows/Tests/badge.svg)][tests]
[![MyPy](https://github.com/nhaines-pro/python-crazyhusk/workflows/MyPy/badge.svg)][mypy]
[![Codecov](https://codecov.io/gh/nhaines-pro/python-crazyhusk/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/5620/badge)](https://bestpractices.coreinfrastructure.org/projects/5620)

[pypi_]: https://pypi.org/project/crazyhusk/
[status]: https://pypi.org/project/crazyhusk/
[python version]: https://pypi.org/project/crazyhusk
[read the docs]: https://crazyhusk.readthedocs.io/
[tests]: https://github.com/nhaines-pro/python-crazyhusk/actions?workflow=Tests
[mypy]: https://github.com/nhaines-pro/python-crazyhusk/actions?workflow=MyPy
[codecov]: https://app.codecov.io/gh/nhaines-pro/python-crazyhusk
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black

## Features

- TODO

## Requirements

- TODO

## Installation

You can install _CrazyHusk_ via [pip] from [PyPI]:

```console
$ pip install crazyhusk
```

## Usage

Please see the [Command-line Reference] for details.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [MIT license][license],
_CrazyHusk_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

[pypi]: https://pypi.org/
[file an issue]: https://github.com/nhaines-pro/python-crazyhusk/issues
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/nhaines-pro/python-crazyhusk/blob/main/LICENSE
[contributor guide]: https://github.com/nhaines-pro/python-crazyhusk/blob/main/CONTRIBUTING.md
[command-line reference]: https://crazyhusk.readthedocs.io/en/latest/usage.html
